﻿using System;
using NUnit.Framework;
using MongoDB.Driver;
using System.Configuration;

namespace MongoSamples
{
    /// <summary>
    /// Test demonstrating how to connect to a MongoDB server and its databases
    /// using <c>MongoClient</c>.
    /// </summary>
    [TestFixture]
    class ConnectionTests
    {
        private MongoClient _client;

        [TestFixtureSetUp]
        public void Setup()
        {
            _client = GetMongoClient();
        }

        [Test]
        public void Test_CanConnectToServer()
        {
            MongoServer server = _client.GetServer();

            Assert.DoesNotThrow(server.Ping);
        }

        [Test]
        public void Test_CanConnectToDatabase()
        {
            MongoServer server = _client.GetServer();
            MongoDatabase database = server.GetDatabase("sample");

            Assert.DoesNotThrow(() => database.GetCollectionNames());
        }

        [TestFixtureTearDown]
        public void TearDown()
        {
            _client = null;
        }

        private static MongoClient GetMongoClient()
        {
            // See http://docs.mongodb.org/manual/reference/connection-string/ for full details
            // on MongoDB connection string format and options.
            const string connectionStringTemplate = "mongodb://{0}:27017";

            string host = ConfigurationManager.AppSettings["Mongo.Host"];
            string connString = String.Format(connectionStringTemplate, host);

            MongoClient client = new MongoClient(connString);

            return client;
        }
    }
}
